..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

API Docs
========

.. automodule:: invenio_admin.ext
   :members:

Views
-----

.. automodule:: invenio_admin.views
   :members:

Forms
-----

.. automodule:: invenio_admin.forms
   :members:

Filters
-------

.. automodule:: invenio_admin.filters
   :members:

Permissions
-----------

.. automodule:: invenio_admin.permissions
   :members:
